import * as _zag_js_anatomy from '@zag-js/anatomy';
import { RequiredBy, PropTypes, DirectionProperty, CommonProperties, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';

declare const anatomy: _zag_js_anatomy.AnatomyInstance<"root" | "label" | "control" | "indicator">;

type CheckedState = boolean | "indeterminate";
interface CheckedChangeDetails {
    checked: CheckedState;
}
type ElementIds = Partial<{
    root: string;
    hiddenInput: string;
    control: string;
    label: string;
}>;
interface PublicContext extends DirectionProperty, CommonProperties {
    /**
     * The ids of the elements in the checkbox. Useful for composition.
     */
    ids?: ElementIds;
    /**
     * Whether the checkbox is disabled
     */
    disabled?: boolean;
    /**
     * Whether the checkbox is invalid
     */
    invalid?: boolean;
    /**
     * Whether the checkbox is required
     */
    required?: boolean;
    /**
     * The checked state of the checkbox
     */
    checked: CheckedState;
    /**
     * Whether the checkbox is read-only
     */
    readOnly?: boolean;
    /**
     * The callback invoked when the checked state changes.
     */
    onCheckedChange?(details: CheckedChangeDetails): void;
    /**
     * The name of the input field in a checkbox.
     * Useful for form submission.
     */
    name?: string;
    /**
     * The id of the form that the checkbox belongs to.
     */
    form?: string;
    /**
     * The value of checkbox input. Useful for form submission.
     * @default "on"
     */
    value: string;
}
type UserDefinedContext = RequiredBy<PublicContext, "id">;
type ComputedContext = Readonly<{
    /**
     * Whether the checkbox is checked
     */
    isIndeterminate: boolean;
    /**
     * Whether the checkbox is checked
     */
    isChecked: boolean;
    /**
     * Whether the checkbox is disabled
     */
    isDisabled: boolean;
}>;
interface PrivateContext {
}
interface MachineContext extends PublicContext, PrivateContext, ComputedContext {
}
interface MachineState {
    value: "ready";
}
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
interface MachineApi<T extends PropTypes = PropTypes> {
    /**
     * Whether the checkbox is checked
     */
    checked: boolean;
    /**
     * Whether the checkbox is disabled
     */
    disabled: boolean | undefined;
    /**
     * Whether the checkbox is indeterminate
     */
    indeterminate: boolean;
    /**
     * Whether the checkbox is focused
     */
    focused: boolean | undefined;
    /**
     *  The checked state of the checkbox
     */
    checkedState: CheckedState;
    /**
     * Function to set the checked state of the checkbox
     */
    setChecked(checked: CheckedState): void;
    /**
     * Function to toggle the checked state of the checkbox
     */
    toggleChecked(): void;
    rootProps: T["label"];
    labelProps: T["element"];
    controlProps: T["element"];
    hiddenInputProps: T["input"];
    indicatorProps: T["element"];
}

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

declare const props: ("value" | "name" | "form" | "dir" | "disabled" | "id" | "checked" | "required" | "ids" | "invalid" | "readOnly" | "onCheckedChange" | "getRootNode")[];
declare const splitProps: <Props extends Partial<UserDefinedContext>>(props: Props) => [Partial<UserDefinedContext>, Omit<Props, "value" | "name" | "form" | "dir" | "disabled" | "id" | "checked" | "required" | "ids" | "invalid" | "readOnly" | "onCheckedChange" | "getRootNode">];

export { type MachineApi as Api, type CheckedChangeDetails, type CheckedState, type UserDefinedContext as Context, type ElementIds, anatomy, connect, machine, props, splitProps };
